/*  easyrec JavaScript API, version 1.0
 *  (c) 2008-2009 Research Studios Austria Forschungsgesellschaft mbH
 *
 *  This is a client based class to communicate with the REST-API of easyrec.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

var defaults = {
    drawingCallback: "drawRecommendationList",
    actionCallback: "void",
    userId:null,
    itemId:"-1",
    sessionId:easyrec_getSessionId(),
    itemUrl:"",
    itemDescription:"",
    itemImageUrl:"",
    timeRange:"ALL",
    numberOfResults:10,
    actionTime:null
};

//////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////  Item Actions ///////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

function easyrec_sendAction(actionType, options) {
    var o = easyrec_extend(options, defaults);

    easyrec_includeJavascript(easyrecApiUrl + actionType + "?" +
            "tenantid=" + tenantId +
            "&apikey=" + apiKey +
            ((o.userId) ? ("&userid=" + o.userId ) : "") +
            "&itemid=" + o.itemId +
            "&sessionid=" + o.sessionId +
            "&itemurl=" + encodeURIComponent(o.itemUrl) +
            "&itemdescription=" + encodeURIComponent(o.itemDescription) +
            "&itemimageurl=" + encodeURIComponent(o.itemImageUrl) +
            "&ratingvalue=" + o.ratingValue +
            "&callback=" + o.actionCallback +
            ((o.actionTime) ? ("&actiontime=" + o.actionTime ) : ""));

}

// This function tracks if a user purchases a specific item.
function easyrec_buy(options) {
    easyrec_sendAction("buy", options);
}

// This function tracks if a user views a specific item.
function easyrec_view(options) {
    easyrec_sendAction("view", options);
}

// This function tracks if a user views a specific item.
function easyrec_rate(options) {
    easyrec_sendAction("rate", options);
}

// This functions call the recommender to retrieve a list
// of similar items to the given one and
// return them in a javascript file
// e.g.
// http://host/api/otherusersalsoviewed.js?tenantid=EASYREC_DEMO&apikey=260b49202287066b8d2449cac92c9888&itemid=42

function easyrec_getRecommendations(recommendationType, options) {
    var o = easyrec_extend(options, defaults);
    easyrec_includeJavascript(easyrecApiUrl + recommendationType + "?" +
            "tenantid=" + tenantId +
            "&apikey=" + apiKey +
            ((o.userId) ? ("&userid=" + o.userId ) : "") +
            "&itemid=" + o.itemId +
            "&callback=" + o.drawingCallback);
}

function easyrec_otherUsersAlsoViewed(options) {
    easyrec_getRecommendations("otherusersalsoviewed", options);
}

function easyrec_otherUsersAlsoBought(options) {
    easyrec_getRecommendations("otherusersalsobought", options);
}

function easyrec_itemsRatedGoodByOtherUsers(options) {
    easyrec_getRecommendations("itemsratedgoodbyotherusers", options);
}

function easyrec_recommendationsForUser(options) {
    easyrec_getRecommendations("recommendationsforuser", options);
}

function easyrec_relatedItems(options) {
    easyrec_getRecommendations("relateditems", options);
}

///////////////////////////////// Ranking functions /////////////////////////////////////
// for all Ranking functions:
// allowed values for timeRange are: DAY, WEEK, MONTH, ALL
// the functions retrieve the daily, weekly, monthly or all time most acted on items


function easyrec_getRankings(rankingType, options) {
    var o = easyrec_extend(options, defaults);

    easyrec_includeJavascript(easyrecApiUrl + rankingType + "?" +
            "tenantid=" + tenantId +
            "&apikey=" + apiKey +
            "&timeRange=" + o.timeRange +
            "&numberOfResults=" + o.numberOfResults +
            "&callback=" + o.drawingCallback);
}


function easyrec_mostViewedItems(options) {
    easyrec_getRankings("mostvieweditems", options);
}

function easyrec_mostBoughtItems(options) {
    easyrec_getRankings("mostboughtitems", options);
}

function easyrec_mostRatedItems(options) {
    easyrec_getRankings("mostrateditems", options);
}

function easyrec_bestRatedItems(options) {
    easyrec_getRankings("bestrateditems", options);
}

function easyrec_worstRatedItems(options) {
    easyrec_getRankings("worstrateditems", options);
}
//////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////// Recommendation DRAWING CALLBACK //////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
function drawRecommendationList(json) {
    drawRecommendationListToDiv(json, "recommenderDiv");
}
function drawRecommendationListToDiv(json, recommenderDiv) {
    if ("undefined" == typeof(json.error)) { // if no error show recommendations

        try {
            var items = json.recommendeditems.item;
        } catch(e) {
            return;
        }

        /* when the object is already in array format, this block will not execute */
        if ("undefined" == typeof(items.length)) {
            items = new Array(items);
        }

        // display recommendations in the DIV layer 'recommendation'
        if (items.length > 0) {
            listString = "<ul>";

            for (x = 0; x < 15 && x < items.length; x++) {
                listString +=
                        "<li><a href='" + items[x].url + "'>"
                                + items[x].description +
                                "</a>" +
                                "</li>";
            }
            document.getElementById(recommenderDiv).innerHTML += listString + "</ul>";

        }
    }
}

function drawRecommendationListWithPictures(json) {
    drawRecommendationListWithPicturesToDiv(json, "recommenderDiv");
}
function drawRecommendationListWithPicturesToDiv(json, recommenderDiv) {
    if ("undefined" == typeof(json.error)) { // if no error show recommendations

        try {
            var items = json.recommendeditems.item;
        } catch(e) {
            return;
        }

        /* when the object is already in array format, this block will not execute */
        if ("undefined" == typeof(items.length)) {
            items = new Array(items);
        }

        // display recommendations in the DIV layer 'recommendation'
        if (items.length > 0) {
            for (x = 0; x < 15 && x < items.length; x++) {
                document.getElementById(recommenderDiv).innerHTML +=
                        "<div style='width:170px;padding:5px;float:left;text-align:center;'>" +
                                "<a href='" + items[x].url + "'>" +
                                "<img style='width:150px;border:0px;' alt='" + items[x].description + "'" +
                                "     src='" + items[x].imageUrl + "'/><br/>"
                                + items[x].description +
                                "</a>" +
                                "</div>";
            }

        }
    }
}

var easyrec_carusel_jqueryJs = false;
var easyrec_carusel_jcarouselJs = false;
function drawRecommendationCarusel(json) {
    drawRecommendationCaruselToDiv(json, "recommenderDiv");
}
function drawRecommendationCaruselToDiv(json, recommenderDiv) {
    if (!easyrec_carusel_jqueryJs || !easyrec_carusel_jcarouselJs) {
        easyrec_includeJavascript(easyrecApiUrl + "../../../js/api/carusel/jquery-1.4.2.min.js", function() {
            easyrec_carusel_jqueryJs = true;
            drawRecommendationCaruselControlFunction(json, recommenderDiv)
        });
        easyrec_includeJavascript(easyrecApiUrl + "../../../js/api/carusel/jquery.jcarousel.min.js", function() {
            easyrec_carusel_jcarouselJs = true;
            drawRecommendationCaruselControlFunction(json, recommenderDiv)
        });
        easyrec_includeCSS(easyrecApiUrl + "../../../js/api/carusel/carousel.css");
    } else {
        drawRecommendationCaruselToDivWithJsReady(json, recommenderDiv);
    }
}

function drawRecommendationCaruselControlFunction(json, recommenderDiv) {
    if (easyrec_carusel_jqueryJs && easyrec_carusel_jcarouselJs) {
        drawRecommendationCaruselToDivWithJsReady(json, recommenderDiv);
    }
}
function drawRecommendationCaruselToDivWithJsReady(json, recommenderDiv) {
    if ("undefined" == typeof(json.error)) { // if no error show recommendations

        var items = json.recommendeditems.item;

        /* when the object is already in array format, this block will not execute */
        if ("undefined" == typeof(items.length)) {
            items = new Array(items);
        }

        // display recommendations in the DIV layer 'recommendation'
        if (items.length > 0) {
            var listString = "<ul id='recCarousel_" + recommenderDiv + "'  class='jcarousel-skin-easyrec'>";

            for (x = 0; x < 15 && x < items.length; x++) {
                listString +=
                        "<li style='text-align:center;'>" +
                                "<a class='jcarousel-skin-easyrec-link' href='" + items[x].url + "'>" +
                                "<img width='150' height='150' style='border:0px;' alt='" + items[x].description + "'" +
                                "     src='" + items[x].imageUrl + "'/><br/>"
                                + items[x].description +
                                "</a>" +
                                "</li>";
            }

            document.getElementById(recommenderDiv).innerHTML += listString + "</ul>";

            jQuery(document).ready(function() {
                jQuery('#recCarousel_' + recommenderDiv).jcarousel({initCallback:drawRecommendationCaruselToDiv_loadButtonPics});
            });
        }
    }
}

function drawRecommendationCaruselToDiv_loadButtonPics() {
    $(".jcarousel-next")[0].style.backgroundImage = "url('" + easyrecApiUrl + "../../../js/api/carusel/next-horizontal.png')";
    $(".jcarousel-prev")[0].style.backgroundImage = "url('" + easyrecApiUrl + "../../../js/api/carusel/prev-horizontal.png')";

}

//////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////// Java Script HELPERS ///////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////

// This function creates a new <SCRIPT> tag with
// the given adress a source.
// (=Dynamic javascript generation)
//
function easyrec_includeJavascript(jsAdr, onLoadFunction) {
    var newJs = document.createElement('script');
    newJs.type = 'text/javascript';
    newJs.src = jsAdr;
    newJs.onload = onLoadFunction;
    document.getElementsByTagName('head')[0].appendChild(newJs);
}

function easyrec_includeCSS(cssAdr) {
    var newCss = document.createElement('link');
    newCss.rel = 'stylesheet'
    newCss.type = 'text/css';
    newCss.href = cssAdr;
    document.getElementsByTagName('head')[0].appendChild(newCss);
}

function easyrec_extend(options, defaults) {
    var target = options;

    for (name in defaults) {
        src = target[ name ];
        copy = defaults[ name ];

        if (src != null) {
            continue;
        } else if (copy !== undefined) {
            target[ name ] = copy;
        }
    }
    // Return the modified object
    return target;
}


//Session functions
function easyrec_createSessionId() {
    var name = "easyrec_sessionVar"
    var value = easyrec_generateSessionId(15);
    String((new Date()).getTime()).replace(/\D/gi, '')
    document.cookie = name + "=" + value + "; path=/";
    return value;
}

function easyrec_generateSessionId(length) {
    chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890";
    returnValue = "";

    for (x = 0; x < length; x++) {
        i = Math.floor(Math.random() * 62);
        returnValue += chars.charAt(i);
    }

    return "JS_" + returnValue;
}

function easyrec_getSessionId() {
    var nameEQ = "easyrec_sessionVar=";
    var ca = document.cookie.split(';');
    for (var i = 0; i < ca.length; i++) {
        var c = ca[i];
        while (c.charAt(0) == ' ') c = c.substring(1, c.length);
        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
    }
    return easyrec_createSessionId();
}